window.Gleam.initSearch([{"doc":"sketch_css","title":"sketch_css","content":"# Sketch CSS\n\n&gt; In case you&#39;re here and don&#39;t know Sketch, take a look at\n&gt; [`sketch` package](https://hexdocs.pm/sketch)!\n\n&gt; This readme is a carbon-copy of the Sketch CSS section in `sketch` readme.\n\nSketch CSS is a tool to generate CSS from Sketch Class definitions. Because pure\nCSS generation is straightforward, `sketch_css` does not need a cache to\ngenerate correct CSS files. Instead, `sketch_css` ships with a CLI tool, able to\nread your Gleam styles files, and output corresponding CSS automagically, while\nproviding an abstraction layer written in Gleam, to make sure you&#39;re using the\nright classes! It&#39;s an other way to leverage Sketch core and enjoy the styling\nin Gleam, while taking advantage of all the static CSS power!\n\nTo run the generator, you have to use the command\n`gleam run -m sketch/css generate` at the root of your project. By default,\n`sketch_css` will try to read all files named `*_styles.gleam`, `*_css.gleam`\nand `*_sketch.gleam` in your `src` folder, no matter where they are. You can put\nthem at root, nested, or in a folder called `css`, `sketch_css` does not care!\nAfter fetching the styles files, `sketch_css` will output your generated CSS\nfiles in a `styles` folder, at the root of the project. They can then be served\nin the way you want. In the same time, `sketch_css` will output Gleam interfaces\nin `src/sketch/styles`, matching your styles files, to use in your project!\n\n### Options\n\nSketch CSS generation has strong defaults, but everything can be customised. To\npass options to Sketch CSS, you have three ways:\n\n- Pass them directly on the CLI. Every option has its equivalent exposed in the\n  CLI.\n- Write them in a `sketch_css.toml` file, at root of your project, next\n  `gleam.toml`.\n- Write them directly in `gleam.toml`, under `[sketch_css]` section.\n\nSketch CSS has 3 distinct options:\n\n- `--dest`, accepting a folder, relative to current directory. It defaults to\n  `styles`.\n- `--src`, accepting a folder, relative to current directory. It defaults to\n  `src`.\n- `--interface`, accepting a folder, relative to current directory. It defaults\n  to `src/sketch/styles`.\n\nWrite directly the folder, path resolution is done with current working\ndirectory as root.\n\n#### Examples\n\n```sh\ngleam run -m sketch_css generate --src=&quot;src&quot; --dest=&quot;styles&quot; --interface=&quot;src/sketch/styles&quot;\n```\n\n```toml\n# sketch_css.toml\nsrc = &quot;src&quot;\ndest = &quot;styles&quot;\ninterface = &quot;src/sketch/styles&quot;\n```\n\n```toml\n# gleam.toml\nname = &quot;name&quot;\nversion = &quot;1.0.0&quot;\n\n[sketch_css]\nsrc = &quot;src&quot;\ndst = &quot;styles&quot;\ninterface = &quot;src/sketch/styles&quot;\n\n[dependencies]\ngleam_stdlib = &quot;&gt;= 0.34.0 and &lt; 2.0.0&quot;\nsketch = &quot;&gt;= 4.0.0 and &lt; 5.0.0&quot;\nsketch_css = &quot;&gt;= 2.0.0 and &lt; 3.0.0&quot;\n\n[dev-dependencies]\ngleeunit = &quot;&gt;= 1.0.0 and &lt; 2.0.0&quot;\n```\n\n### A note on generation algorithm\n\nBecause a Sketch `Class` can be generated in multiple ways, and with variable,\nSketch CSS takes that into account. Every simple Sketch `Class` will be iso\ngenerated in CSS, but every Sketch `Class` that contains variable will be\ngenerated with the variable taken into account! Sketch CSS being opinionated, it\ngenerates the class, with a CSS variable, letting you update it, override it,\netc.\n\nSketch CSS also acts as a basic interpreter. It means you can write basic\nconstants or variables, and they will be taking into account. Be sure to write\nclasses like you would do in CSS yet: Sketch CSS does not execute your\nfunctions!\n\n### Example\n\n```gleam\n// src/main_styles.gleam\nimport sketch/css\n\npub fn flexer() {\n  let display = &quot;flex&quot;\n  css.class([css.display(display)])\n}\n\nfn direction(flex_direction: String) {\n  css.flex_direction(flex_direction)\n}\n\npub fn flexer_direction(flex_direction: String) {\n  css.class([\n    css.compose(flexer()),\n    direction(flex_direction),\n  ])\n}\n```\n\n```css\n/* styles/main_styles.css */\n.main_styles-flexer {\n  display: flex;\n}\n\n.main_styles-flexer_direction {\n  display: flex;\n  flex-direction: var(--flex-direction);\n}\n```\n\n```gleam\n// src/sketch/styles/main_styles.gleam\npub const flexer = &quot;main_styles-flexer&quot;\n\npub const flexer_direction = &quot;main_styles-flexer_direction&quot;\n```\n","url":"index.html"},{"doc":"sketch_css","title":"main","content":"pub fn main() -&gt; Nil\n The `main` function is used as an entrypoint for Sketch CSS. That function\n is not meant to be used in your code, but is called when you use `gleam run`\n from the command line.\n\n \n gleam run -m sketch_css\n \nSynonyms:\nsketch_css.main\nsketch_css main","url":"sketch_css.html#main"},{"doc":"sketch_css","title":"sketch_css","content":"","url":"sketch_css.html"}]);